#include <IRremote.h>

#define IR_RECEIVE_PIN 2

// Motor A connections (Left) - DRV8833
const int motorA_IN1 = 10;
const int motorA_IN2 = 9;

// Motor B connections (right) - DRV8833
const int motorB_IN1 = 6;
const int motorB_IN2 = 5;

// Motor speeds (0-255)
int motorASpeed = 250; // Default full speed
int motorBSpeed = 250; // Default full speed

void setup() {
  Serial.begin(9600);
  IrReceiver.begin(IR_RECEIVE_PIN);

  // Motor pins as outputs
  pinMode(motorA_IN1, OUTPUT);
  pinMode(motorA_IN2, OUTPUT);
  pinMode(motorB_IN1, OUTPUT);
  pinMode(motorB_IN2, OUTPUT);

  stopMotors(); // Initialize motors to stop
}

void loop() {
  if (IrReceiver.decode()) {
    Serial.println(IrReceiver.decodedIRData.command); // Print the received command

    switch (IrReceiver.decodedIRData.command) {
      case 96: // Forward
        moveForward();
        break;
      case 98: // Right
        moveRight();
        break;
      case 101: // Left
        moveLeft();
        break;
      case 97: // Reverse
        moveReverse();
        break;
      case 104: // Stop
        stopMotors();
        break;
      default:
        Serial.println("Unknown command");
        break;
    }
    IrReceiver.resume(); // Receive the next value
  }
}

void moveForward() {
  digitalWrite(motorA_IN1, HIGH);
  digitalWrite(motorA_IN2, LOW);
  digitalWrite(motorB_IN1, HIGH);
  digitalWrite(motorB_IN2, LOW);
  analogWrite(motorA_IN1, motorASpeed);
  analogWrite(motorB_IN1, motorBSpeed);
  Serial.println("Forward");
}

void moveReverse() {
  digitalWrite(motorA_IN1, LOW);
  digitalWrite(motorA_IN2, HIGH);
  digitalWrite(motorB_IN1, LOW);
  digitalWrite(motorB_IN2, HIGH);
  analogWrite(motorA_IN2, motorASpeed);
  analogWrite(motorB_IN2, motorBSpeed);
  Serial.println("Reverse");
}

void moveRight() {
  digitalWrite(motorA_IN1, HIGH);
  digitalWrite(motorA_IN2, LOW);
  digitalWrite(motorB_IN1, LOW);
  digitalWrite(motorB_IN2, HIGH);
  analogWrite(motorA_IN1, motorASpeed);
  analogWrite(motorB_IN2, motorBSpeed);
  Serial.println("Right");
}

void moveLeft() {
  digitalWrite(motorA_IN1, LOW);
  digitalWrite(motorA_IN2, HIGH);
  digitalWrite(motorB_IN1, HIGH);
  digitalWrite(motorB_IN2, LOW);
  analogWrite(motorA_IN2, motorASpeed);
  analogWrite(motorB_IN1, motorBSpeed);
  Serial.println("Left");
}

void stopMotors() {
  digitalWrite(motorA_IN1, LOW);
  digitalWrite(motorA_IN2, LOW);
  digitalWrite(motorB_IN1, LOW);
  digitalWrite(motorB_IN2, LOW);
  Serial.println("Stop");
}
